@@ -7,8 +7,6 @@ from je_api_testka.utils.executor.action_executor import execute_action
 from je_api_testka.utils.executor.action_executor import execute_files
 from je_api_testka.utils.executor.action_executor import executor
 from je_api_testka.utils.executor.action_executor import add_command_to_executor
-# project
-from je_api_testka.utils.file_process.create_project_structure import create_template_dir
 # file process
 from je_api_testka.utils.file_process.get_dir_file_list import get_dir_files_as_list
 # html_output
